@@ -39,45 +39,75 @@ sub _build_config {
     if (! -d $self->{LOCATION}) {
 	   confess("Cannot open directory " . $self->{LOCATION} );
     }
-    
+
     return 1;
 }
 
 # return the content of the file
 sub get {
-    
-    my $self = shift;
-   
-    my $filename = $self->_sanitize_path( shift );
 
-    my $content;
-    if (-r $filename) {
-	  $content = do {
+    my $self = shift;
+    my $path = shift;
+
+    my $filename = $self->_sanitize_path( $path );
+
+    if (! -r $filename) {
+        return $self->_node_not_exists( $path );
+    }
+
+	my $content = do {
 	  local $INPUT_RECORD_SEPARATOR;
 	  open my $fh, '<', $filename;
 	  <$fh>;
-      };
-    }
-
+    };
     return $content;
 }
 
+sub get_meta {
+    my $self = shift;
+
+    # If we have no path, we tell the caller that we are a connector
+    my @path = $self->_build_path_with_prefix( shift );
+    if (scalar @path == 0) {
+        return { TYPE  => "connector" };
+    }
+
+    return {TYPE  => "scalar" };
+}
+
+
+sub exists {
+
+    my $self = shift;
+
+    # No path = connector root which always exists
+    my @path = $self->_build_path_with_prefix( shift );
+    if (scalar @path == 0) {
+        return 1;
+    }
+
+    my $filename = $self->_sanitize_path( \@path );
+
+    return -r $filename;
+}
+
+
 # return the content of the file
 sub set {
-    
+
     my $self = shift;
     my $file = shift;
     my $data = shift;
-   
+
     my $filename = $self->_sanitize_path( $file, $data );
 
     my $content;
     if ($self->content()) {
         $self->log()->debug('Process template for content ' . $self->content());
-        my $template = Template->new({});        
-        
+        my $template = Template->new({});
+
         $data = { DATA => $data } if (ref $data eq '');
-                
+
         $template->process( \$self->content(), $data, \$content) || die "Error processing content template.";
     } else {
         if (ref $data ne '') {
@@ -90,23 +120,23 @@ sub set {
     if ($mode eq 'fail' && -f $filename) {
         die "File $filename exists";
     }
-    
+
     if ($mode eq 'silent' && -f $filename) {
         return;
     }
-    
+
     if ($mode eq 'append' && -f $filename) {
         open FILE, ">>$filename" || die "Unable to open file for appending";
     } else {
         open FILE, ">$filename" || die "Unable to open file for writing";
     }
-    
+
     print FILE $content;
     close FILE;
-    
+
     #FIXME - some error handling might not hurt
-    
-    return 1;    
+
+    return 1;
 }
 
 
@@ -123,17 +153,17 @@ sub _sanitize_path {
     if ($self->file()) {
         my $pattern = $self->file();
         my $template = Template->new({});
-        $self->log()->debug('Process template ' . $pattern);  
+        $self->log()->debug('Process template ' . $pattern);
         $template->process( \$pattern, { ARGS => \@args, DATA => $data }, \$file) || die "Error processing argument template.";
     } else {
         $file = join $self->DELIMITER(), @args;
     }
 
-    $file =~ s/[^\s\w\.]//g;
+    $file =~ s/[^\s\w\.-]//g;
     my $filename = $self->{LOCATION}.'/'.$file;
 
     $self->log()->debug('Filename evaluated to ' . $filename);
-        
+
     return $filename;
 }
 
@@ -154,20 +184,20 @@ Highly configurable file writter/reader.
 =head1 Parameters
 
 =over
- 
+
 =item LOCATION
 
 The base directory where the files are located. This parameter is mandatory.
 
 =item file
 
-Pattern for Template Toolkit to build the filename. 
+Pattern for Template Toolkit to build the filename.
 The path components are available in the key ARGS. In set mode the unfiltered
 data is available in key DATA.
 
 =item content
 
-Pattern for Template Toolkit to build the content. The data is passed 
+Pattern for Template Toolkit to build the content. The data is passed
 "as is". If data is a scalar, it is wrapped into a hash using DATA as key.
 
 =item ifexists
@@ -188,13 +218,13 @@ Pattern for Template Toolkit to build the content. The data is passed
 
 =head2 set
 
-Write data to a file.  
+Write data to a file.
 
     $conn->set('filename', { NAME => 'Oliver', 'ROLE' => 'Administrator' });
 
-See the file parameter how to control the filename. 
-By default, files are silently overwritten if they exist. See the I<ifexists> 
-parameter for an alternative behaviour. 
+See the file parameter how to control the filename.
+By default, files are silently overwritten if they exist. See the I<ifexists>
+parameter for an alternative behaviour.
 
 =head2 get
 
@@ -211,6 +241,6 @@ Fetch data from a file. See the file parameter how to control the filename.
     });
 
     $conn->set('test', { NAME => 'Oliver' });
-    
-Results in a file I</var/data/test.txt> with the content I<Hello Oliver>.    
+
+Results in a file I</var/data/test.txt> with the content I<Hello Oliver>.
 
